import MasterControllerBase = require("sas/dm/commons/controller/base/MasterControllerBase");
import Context = require("sas/dm/commons/context/Context");
import ErrorResponse = require("sas/dm/commons/model/ErrorResponse");
import MasterController = require("sas/dm/businessdata/controller/MasterController");
import CommonSharedProperties = require("sas/dm/commons/util/SharedProperties");
import TermType = require("sas/dm/businessdata/model/TermType");
import Unbindable = require("sas/dm/commons/util/binding/Unbindable");
import BindingUtils = require("sas/dm/commons/util/binding/BindingUtils");
import TermsViewMode = require("sas/dm/businessdata/components/termsview/TermsViewMode");
import GrantedCapabilitiesCache = require("sas/dm/businessdata/util/GrantedCapabilitiesCache");
import TypeAttribute = require("../model/TypeAttribute");

class TermTypeController extends MasterControllerBase {

    //public properties
    private _globalController:MasterController;
    private _termType:TermType;
    private _termsViewModeWatcher: Unbindable;
    private _termsViewMode: TermsViewMode;
    private _editMode:boolean;



    public get globalController(): MasterController {
        return this._globalController;
    }

    public get termType(): TermType {
        return this._termType;
    }

    public set termType(value: TermType) {
        this._termType = value;
    }

    public get termsViewMode(): TermsViewMode {
        return this._termsViewMode;
    }

    public set termsViewMode(value: TermsViewMode) {
        this._termsViewMode = value;
    }

    public get editMode(): boolean {
        return this._editMode;
    }

    public set editMode(value: boolean) {
        this._editMode = value;
    }

    public save(successHandler: (response: TermType) => void, errorHandler: (error: ErrorResponse) => void):void {
        // set sortOrder for attribute values(single select list or multiple select list)
        if (this.termType.attributes) {
            this.termType.attributes.map(function (attr: TypeAttribute) {
                if (attr.renderer == TypeAttribute.RENDERER_SINGLE_SELECT_LIST || attr.renderer == TypeAttribute.RENDERER_MULTI_SELECT_LIST) {
                    if (attr.values) {
                        for (let i: number = 0; i < attr.values.length; i++) {
                            attr.values[i].sortOrder = i;
                        }
                    }
                }
            });
        }
        //if a new TermType
        if(this.termType.id =="0"){
            //call to create the termType with midTier API
            this.globalController.createTermType(this.termType, successHandler, errorHandler);
        }
        //otherwise, updating an existing termType
        else {
            //call to update the termType with midTier API
            this.globalController.updateTermType(this.termType, successHandler, errorHandler);
        }
    }

    constructor() {
        super();
    }

    public setMasterContext(context:Context):void {
        super.setMasterContext(context);
        const controllers: Array<any> = context.getObject(CommonSharedProperties.CONTEXT_KEY_CONTROLLER, true);
        this._globalController = <MasterController> controllers[controllers.length - 1];

        this.unbind();
        this._termsViewModeWatcher = BindingUtils.handlePropertyChange(this._globalController, "termsViewMode",
            (newTermsViewMode: TermsViewMode, oldTermsViewMode: TermsViewMode) => {
                this.termsViewMode = newTermsViewMode;
                this.editMode = !(this.termsViewMode==TermsViewMode.SNAPSHOTVIEW);
            }, true);
    }

    protected unbind(): void {
        BindingUtils.unbind(this._termsViewModeWatcher);
    }

}
export = TermTypeController;
